var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'deprecated.xml',
'old_atomic.xml',
'old_mat_mul.cpp.xml',
'old_mat_mul.hpp.xml'
];
var list_down3 = [
'include_deprecated.xml',
'fundeprecated.xml',
'comparechange.xml',
'omp_max_thread.xml',
'tracknewdel.xml',
'omp_alloc.xml',
'memory_leak.xml',
'epsilon.xml',
'test_vector.xml',
'cppad_ipopt_nlp.xml',
'old_atomic.xml',
'zdouble.xml',
'autotools.xml'
];
var list_down2 = [
'old_reciprocal.cpp.xml',
'old_usead_1.cpp.xml',
'old_usead_2.cpp.xml',
'old_tan.cpp.xml',
'old_mat_mul.cpp.xml'
];
var list_down1 = [
'old_mat_mul.hpp.xml'
];
var list_current0 = [
'old_mat_mul.hpp.xml#Syntax',
'old_mat_mul.hpp.xml#Example',
'old_mat_mul.hpp.xml#Begin Source',
'old_mat_mul.hpp.xml#Extra Call Information',
'old_mat_mul.hpp.xml#Matrix Indexing',
'old_mat_mul.hpp.xml#One Matrix Multiply',
'old_mat_mul.hpp.xml#Reverse Partials One Order',
'old_mat_mul.hpp.xml#Set Union',
'old_mat_mul.hpp.xml#CppAD User Atomic Callback Functions',
'old_mat_mul.hpp.xml#Declare mat_mul Function'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
